@@ -17,13 +17,17 @@ datasummary_df <- function(data,
                            escape = TRUE,
                            ...) {
 
-  sanitize_output(output)
-  sanitize_escape(escape)
+  sanitize_output(output) # before sanitize_escape
+  sanitize_escape(escape) # after sanitize_output
 
   checkmate::assert_data_frame(data)
 
+  notes <- escape_string(notes)
+  title <- escape_string(title)
+
   for (n in colnames(data)) {
-    data[[n]] <- rounding(data[[n]], fmt)
+    fmt <- sanitize_fmt(fmt)
+    data[[n]] <- fmt(data[[n]])
   }
 
   factory(data,
